@@ -1,8 +1,9 @@
 ### These functions are supposed to run in SPMD, even when pbd.mode = "mw".
 
 pbdSapply <- function(X, FUN, ..., simplify = TRUE, USE.NAMES = TRUE,
-    pbd.mode = c("mw", "spmd"), rank.source = .SPMD.CT$rank.root,
-    comm = .SPMD.CT$comm, bcast = FALSE){
+    pbd.mode = c("mw", "spmd", "dist"),
+    rank.source = .pbd_env$SPMD.CT$rank.root,
+    comm = .pbd_env$SPMD.CT$comm, bcast = FALSE, barrier = TRUE){
   COMM.SIZE <- spmd.comm.size(comm)
   COMM.RANK <- spmd.comm.rank(comm)
 
@@ -23,9 +24,13 @@ pbdSapply <- function(X, FUN, ..., simplify = TRUE, USE.NAMES = TRUE,
     }
 
     new.X <- spmd.scatter.object(new.X, rank.source = rank.source, comm = comm)
+  } else if(pbd.mode[1] == "spmd"){
+    alljid <- get.jid(length(X), comm = comm)
+    new.X <- sapply(alljid, list.to.list, X) 
+  } else if(pbd.mode[1] == "dist"){
+    nex.X <- X
   } else{
-     alljid <- get.jid(length(X), comm = comm)
-     new.X <- sapply(alljid, list.to.list, X) 
+    comm.stop("pbd.mode is not found.")
   }
 
   ### Run as SPMD.
@@ -52,6 +57,10 @@ pbdSapply <- function(X, FUN, ..., simplify = TRUE, USE.NAMES = TRUE,
     }
   }
 
+  if(barrier){
+    spmd.barrier(comm = comm)
+  }
+
   ret
 } # End of pbdSapply().
 
