@@ -1,7 +1,7 @@
 ### All common functions.
 
-comm.allcommon <- function(x, comm = .SPMD.CT$comm,
-    lazy.check = .SPMD.CT$lazy.check){
+comm.allcommon <- function(x, comm = .pbd_env$SPMD.CT$comm,
+    lazy.check = .pbd_env$SPMD.CT$lazy.check){
   if(lazy.check){
     ### Faster but dangerous.
     ret <- allreduce(x, comm = comm) / spmd.comm.size(comm) == x
@@ -15,7 +15,7 @@ comm.allcommon <- function(x, comm = .SPMD.CT$comm,
 
 
 ### Internal only.
-comm.allcommon.integer <- function(x, comm = .SPMD.CT$comm){
+comm.allcommon.integer <- function(x, comm = .pbd_env$SPMD.CT$comm){
   x <- as.integer(x)
   spmd.allreduce.integer(x, integer(length(x)), comm = comm, op = "band") == x
 } # End of comm.allcommon.integer().
