@@ -2,8 +2,9 @@
 
 ### Default method.
 spmd.gather.default <- function(x, x.buffer = NULL, x.count = NULL,
-    displs = NULL, rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    displs = NULL, rank.dest = .pbd_env$SPMD.CT$rank.root,
+    comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   all.array <- spmd.allreduce.integer(as.integer(is.array(x)),
                                       integer(1), op = "sum",
                                       comm = comm) == spmd.comm.size(comm)
@@ -19,8 +20,8 @@ spmd.gatherv.default <- spmd.gather.default
 
 ### For gather and basic types.
 spmd.gather.integer <- function(x, x.buffer, x.count = NULL, displs = NULL,
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gather_integer", x, x.buffer,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
@@ -30,8 +31,8 @@ spmd.gather.integer <- function(x, x.buffer, x.count = NULL, displs = NULL,
 } # End of spmd.gather.double().
 
 spmd.gather.double <- function(x, x.buffer, x.count = NULL, displs = NULL,
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gather_double", x, x.buffer,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
@@ -41,8 +42,8 @@ spmd.gather.double <- function(x, x.buffer, x.count = NULL, displs = NULL,
 } # End of spmd.gather.double().
 
 spmd.gather.raw <- function(x, x.buffer, x.count = NULL, displs = NULL,
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gather_raw", x, x.buffer,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
@@ -55,8 +56,8 @@ spmd.gather.raw <- function(x, x.buffer, x.count = NULL, displs = NULL,
 ### For gatherv and basic types.
 spmd.gatherv.integer <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gatherv_integer", x, x.buffer, x.count, displs,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
@@ -67,8 +68,8 @@ spmd.gatherv.integer <- function(x, x.buffer, x.count,
 
 spmd.gatherv.double <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gatherv_double", x, x.buffer, x.count, displs,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
@@ -79,8 +80,8 @@ spmd.gatherv.double <- function(x, x.buffer, x.count,
 
 spmd.gatherv.raw <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    rank.dest = .SPMD.CT$rank.root, comm = .SPMD.CT$comm,
-    unlist = .SPMD.CT$unlist){
+    rank.dest = .pbd_env$SPMD.CT$rank.root, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- .Call("spmd_gatherv_raw", x, x.buffer, x.count, displs,
                as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
