@@ -1,8 +1,7 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
-### Initial.
+### Initialize
 suppressMessages(library(pbdMPI, quietly = TRUE))
-init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
 
