@@ -9,7 +9,7 @@ SEXP spmd_bcast_integer(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -22,7 +22,7 @@ SEXP spmd_bcast_integer(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, SPMD_SHORT_LEN_MAX,
-			MPI_INT, C_rank_source, comm[C_comm]));
+			MPI_INT, C_rank_source, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
 	}
@@ -37,12 +37,12 @@ SEXP spmd_bcast_integer(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, (int) C_length_send_data,
-			MPI_INT, C_rank_source, comm[C_comm]));
+			MPI_INT, C_rank_source, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Bcast(INTEGER(R_send_data), LENGTH(R_send_data),
 		MPI_INT, INTEGER(R_rank_source)[0],
-		comm[INTEGER(R_comm)[0]]));
+		global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_send_data);
 } /* End of spmd_bcast_integer(). */
@@ -55,7 +55,7 @@ SEXP spmd_bcast_double(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -68,7 +68,7 @@ SEXP spmd_bcast_double(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, SPMD_SHORT_LEN_MAX,
-			MPI_DOUBLE, C_rank_source, comm[C_comm]));
+			MPI_DOUBLE, C_rank_source, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
 	}
@@ -83,12 +83,12 @@ SEXP spmd_bcast_double(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, (int) C_length_send_data,
-			MPI_DOUBLE, C_rank_source, comm[C_comm]));
+			MPI_DOUBLE, C_rank_source, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Bcast(REAL(R_send_data), LENGTH(R_send_data),
 		MPI_DOUBLE, INTEGER(R_rank_source)[0],
-		comm[INTEGER(R_comm)[0]]));
+		global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_send_data);
 } /* End of spmd_bcast_double(). */
@@ -101,7 +101,7 @@ SEXP spmd_bcast_raw(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -114,7 +114,7 @@ SEXP spmd_bcast_raw(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, SPMD_SHORT_LEN_MAX,
-			MPI_BYTE, C_rank_source, comm[C_comm]));
+			MPI_BYTE, C_rank_source, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
 	}
@@ -129,12 +129,12 @@ SEXP spmd_bcast_raw(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 		#endif
 
 		spmd_errhandler(MPI_Bcast(C_send_data, (int) C_length_send_data,
-			MPI_BYTE, C_rank_source, comm[C_comm]));
+			MPI_BYTE, C_rank_source, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Bcast(RAW(R_send_data), LENGTH(R_send_data),
 		MPI_BYTE, INTEGER(R_rank_source)[0],
-		comm[INTEGER(R_comm)[0]]));
+		global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_send_data);
 } /* End of spmd_bcast_raw(). */
@@ -143,7 +143,7 @@ SEXP spmd_bcast_string(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm){
 	char *C_send_data = CHARPT(R_send_data, 0);
 	spmd_errhandler(MPI_Bcast(C_send_data, strlen(C_send_data),
 		MPI_CHAR, INTEGER(R_rank_source)[0],
-		comm[INTEGER(R_comm)[0]]));
+		global_spmd_comm[INTEGER(R_comm)[0]]));
 	return(R_send_data);
 } /* End of spmd_bcast_string(). */
 
